//
//  YHMsgViewModel.swift
//  galaxy
//
//  Created by edy on 2024/4/15.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import SmartCodable

class YHMsgViewModel: NSObject {
    
    var msgList: YHMsgListModel?
    var msgDetailList : [YHDetailMessageModel] = []
    
    func getUnreadMsgList(_ callBackBlock:@escaping (_ success: Bool, _ error:YHErrorModel?)->()) {
        
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Message.unreadMsgList
        let _ = YHNetRequest.getRequest(url: strUrl) { json, code in
            
            let dic = json.data
            printLog("model 是 ==> \(json)")
            if json.code == 200 {
                guard let result = YHMsgListModel.deserialize(dict: dic as? Dictionary ) else {
                    let error = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    self.msgList = nil
                    callBackBlock(false, error)
                    return
                }
                self.msgList = result
                callBackBlock(true, nil)
                
            } else {
                self.msgList = nil
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code), errorMsg: json.msg)
                callBackBlock(false, error)
            }
            
        } failBlock: { error in
            self.msgList = nil
            callBackBlock(false, error)
        }
    }
    
    func getMsgDetailList(type:Int, _ callBackBlock:@escaping (_ success: Bool, _ error:YHErrorModel?)->()) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Message.msgDetaiList
        let params = ["type": type]
        let _ = YHNetRequest.postRequest(url: strUrl, params: params) { json, code in
            
            let dic = json.data
            printLog("model 是 ==> \(json)")
            if json.code == 200 {
                
                guard let arr = [YHDetailMessageModel].deserialize(array: dic as? [Any]) else {
                    let error = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    self.msgDetailList = []
                    callBackBlock(false, error)
                    return
                }
                self.msgDetailList.removeAll()
                for item in arr {
                    if let item = item {
                        self.msgDetailList.append(item)
                    }
                }
                callBackBlock(true, nil)
                
            } else {
                self.msgDetailList = []
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code), errorMsg: json.msg)
                callBackBlock(false, error)
            }
            
        } failBlock: { error in
            self.msgDetailList = []
            callBackBlock(false, error)
        }
    }
    
    func readMessages(type:Int, msgIds:[Int], _ callBackBlock:@escaping (_ success: Bool, _ error:YHErrorModel?)->()) {
        
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Message.readMsg
        
        let params:[String : Any] = ["type": type,
                                     "ids": msgIds]
        let _ = YHNetRequest.postRequest(url: strUrl, params: params) { json, code in
            
            let dic = json.data
            printLog("model 是 ==> \(json)")
            if json.code == 200 {
                callBackBlock(true, nil)
                
            } else {
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code), errorMsg: json.msg)
                callBackBlock(false, error)
            }
            
        } failBlock: { error in
            self.msgList = nil
            callBackBlock(false, error)
        }
        
    }
}
